@@ -20,5 +20,17 @@ class InvalidAuth(Exception):
     def __init__(self,Note:str=""):
         pass
 class NonExsistant(Exception):
+    def __init__(self,Note:str=""):
+        pass
+class IndexOutOfItems(Exception):
+    def __init__(self,Note:str=""):
+        pass
+class ItemNotFound(Exception):
+    def __init__(self,Note:str=""):
+        pass
+class MissingArgument(Exception):
+    def __init__(self,Note:str=""):
+        pass
+class FormatError(Exception):
     def __init__(self,Note:str=""):
         pass
\ No newline at end of file
