@@ -1,15 +1,18 @@
 import multiprocessing,os,mediapipe
+import httpx as x
 
 __ext_DCF__ = False
 class using:
-    def create_process(target,args):
+    def __init__(self):
+        pass
+    def create_process(self,target,args):
         p = multiprocessing.Process(target=target,args=args)
         return p
-    def start_process(Process):
+    def start_process(self,Process):
         global _mp_tkt_process
         Process.start()
         _mp_tkt_process=Process
-    def pull_values(V:str):
+    def pull_values(self,V:str):
         t,hex=V.split('{"value":"',1)
         hex,t=hex.split('","clean":"',1)
         t,rgb=V.split('"value":"rgb',1)
@@ -19,16 +22,16 @@ class using:
         t,hsv=V.split(',"value":"hsv',1)
         hsv,t=hsv.split('","h":',1)
         return (hex,rgb,hsl,hsv,V)
-    def del_files(dat: str,log:bool):
+    def del_files(self,dat: str,log:bool):
         for I in os.listdir(dat):
             E = (dat + "/" + I)
             if log == True:print(f'Deleting : {E}')
             if os.path.isfile(E):
                 os.remove(E)
             elif os.path.isdir(E):
-                using.del_files(E,log)
+                self.del_files(E,log)
 
-    def del_folders(dat: str,log:bool):
+    def del_folders(self,dat: str,log:bool):
         for I in os.listdir(dat):
             E = (dat + "/" + I)
             if log == True:print(f'Deleting : {E}')
@@ -36,7 +39,7 @@ class using:
                 try:
                     os.rmdir(E)
                 except OSError:
-                    using.del_folders(E,log)
+                    self.del_folders(E,log)
                     os.rmdir(E)
         os.rmdir(dat)
 class Q:
@@ -155,17 +158,4 @@ class qr:
         self.r_rectangle = self.raw_decoded.rect
         self.polygon = self.raw_decoded.polygon
         self.rectangle = self.raw_decoded.rect.left,self.raw_decoded.rect.top,self.raw_decoded.rect.width,self.raw_decoded.rect.height
-if __ext_DCF__ == True:
-    class DCF:
-        Send = Discord_framework.send
-        Friends = Discord_framework.friends
-        Info = Discord_framework.info
-        Token = Discord_framework.token
-        All = Discord_framework
-else:
-    class DCF:
-        Send = None
-        Friends = None
-        Info = None
-        Token = None
-        All = None
\ No newline at end of file
+using = using()
\ No newline at end of file
