@@ -3,6 +3,7 @@ import cv2,mediapipe,time,keyboard,numpy
 import pytesseract.pytesseract
 from pyzbar.pyzbar import decode as qr_decode_dat
 from .parse import Hand,Pose,Face,FaceMesh,ScannedText,qr
+import numpy as np,imutils
 class Utils:
     def absa(c1:tuple,c2:tuple,t:int):
         """
@@ -190,43 +191,82 @@ class Gestures:
     The locked gestures (ROCK,SCISSOR,PAPER) look at the fingers up and
     returns true if the right fingers are up/down.
     """
-    def INDEX_finger_up(hand:Hand):
-        L1 = hand.INDEX
+    def __init__(self,hand:Hand):
+        self.hand = hand
+    def INDEX_finger_up(self):
+        L1 = self.hand.INDEX
         if L1[0][1] > L1[3][1]:return True
         else:return False
-    def THUMB_finger_up(hand:Hand):
-        L1 = hand.THUMB
+    def THUMB_finger_up(self):
+        L1 = self.hand.THUMB
         if L1[0][1] > L1[3][1] and not Utils.absa(L1[0],L1[1],22):
             return True
         else:
             return False
-    def PINKY_finger_up(hand:Hand):
-        L1 = hand.PINKY
+    def PINKY_finger_up(self):
+        L1 = self.hand.PINKY
         if L1[0][1] > L1[3][1]:return True
         else:return False
-    def RING_finger_up(hand:Hand):
-        L1 = hand.RING
+    def RING_finger_up(self):
+        L1 = self.hand.RING
         if L1[0][1] > L1[3][1]:return True
         else:return False
-    def MIDDLE_finger_up(hand:Hand):
-        L1 = hand.MIDDLE
+    def MIDDLE_finger_up(self):
+        L1 = self.hand.MIDDLE
         if L1[0][1] > L1[3][1]:return True
         else:return False
-    def paper(hand:Hand):
-        if Gestures.INDEX_finger_up(hand) and Gestures.RING_finger_up(hand) and Gestures.PINKY_finger_up(hand) and Gestures.MIDDLE_finger_up(hand):
+    def paper(self):
+        if self.INDEX_finger_up() and self.RING_finger_up() and self.PINKY_finger_up() and self.MIDDLE_finger_up():
             return True
         else:
             return False
-    def rock(hand:Hand):
-        if Gestures.INDEX_finger_up(hand) or Gestures.RING_finger_up(hand) or Gestures.PINKY_finger_up(hand) or Gestures.MIDDLE_finger_up(hand):
+    def rock(self):
+        if self.INDEX_finger_up() or self.RING_finger_up() or self.PINKY_finger_up() or self.MIDDLE_finger_up():
             return False
         else:
             return True
-    def scissor(hand:Hand):
-        if Gestures.INDEX_finger_up(hand) and Gestures.MIDDLE_finger_up(hand) and not Gestures.RING_finger_up(hand) and not Gestures.PINKY_finger_up(hand):
+    def scissor(self):
+        if self.INDEX_finger_up() and self.MIDDLE_finger_up() and not self.RING_finger_up() and not self.PINKY_finger_up():
             return True
         else:
             return False
+class MixDetection:
+    def __init__(self,img):
+        self.img = img
+    def Detect_License_Placte(self):
+        img = cv2.resize(self.img, (600, 400))
+        gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
+        gray = cv2.bilateralFilter(gray, 13, 15, 15)
+        edged = cv2.Canny(gray, 30, 200)
+        contours = cv2.findContours(edged.copy(), cv2.RETR_TREE, cv2.CHAIN_APPROX_SIMPLE)
+        contours = imutils.grab_contours(contours)
+        contours = sorted(contours, key=cv2.contourArea, reverse=True)[:10]
+        screenCnt = None
+        for c in contours:
+            peri = cv2.arcLength(c, True)
+            approx = cv2.approxPolyDP(c, 0.018 * peri, True)
+            if len(approx) == 4:
+                screenCnt = approx
+                break
+        if screenCnt is None:
+            detected = 0
+            return [None,None]
+        else:
+            detected = 1
+        if detected == 1:
+            cv2.drawContours(img, [screenCnt], -1, (0, 0, 255), 3)
+        try:
+            mask = np.zeros(gray.shape, np.uint8)
+            new_image = cv2.drawContours(mask, [screenCnt], 0, 255, -1, )
+            self.new_image = cv2.bitwise_and(img, img, mask=mask)
+            (x, y) = np.where(mask == 255)
+            (topx, topy) = (np.min(x), np.min(y))
+            (bottomx, bottomy) = (np.max(x), np.max(y))
+            Cropped = gray[topx:bottomx + 1, topy:bottomy + 1]
+            self.Cropped = cv2.resize(Cropped, (400, 200))
+        except:
+            return [None,None]
+        return [self.Cropped,self.new_image]
 class Segmentation:
     def __init__(self,rep_img,rem_perc:float,model_sel=0,body=False):
         """
@@ -293,6 +333,11 @@ class qrbar_code:
             self.object = qr(img,self.raw_)
         else:
             self.object = None
+    def qr_shown(self):
+        if self.object == None:
+            return False
+        else:
+            return True
     def get_text(self):
         if self.object == None:return
         obj : qr = self.object
@@ -302,6 +347,52 @@ class qrbar_code:
         obj: qr = self.object
         return obj
 class Examples:
+    def x3_test_all(img):
+        report = []
+        try:
+            q = qrbar_code(img)
+            q.get_all_data()
+            report.append((True, 'Test succeeded'))
+        except Exception as ex:
+            print(len(report) + 1)
+            report.append(str(ex))
+        try:
+            q = HandDetector()
+            q.get_Hands(img)
+            report.append((True, 'Test succeeded'))
+        except Exception as ex:
+            print(len(report) + 1)
+            report.append(str(ex))
+        try:
+            q = FaceDetection()
+            q.get_faces(img)
+            report.append((True,'Test succeeded'))
+        except Exception as ex:
+            print(len(report) + 1)
+            report.append((False,str(ex)))
+        try:
+            q = PoseDetector(True)
+            q.get_Pose(img)
+            report.append((True,'Test succeeded'))
+        except Exception as ex:
+            print(len(report) + 1)
+            report.append((False,str(ex)))
+        try:
+            q = FaceMeshDetector()
+            q.get_faces(img)
+            report.append((True,'Test succeeded'))
+        except Exception as ex:
+            print(len(report) + 1)
+            report.append((False,str(ex)))
+        try:
+            q = Segmentation(img,0.9)
+            q.segment(img)
+            report.append((True,'Test succeeded'))
+        except Exception as ex:
+            print(len(report) + 1)
+            report.append((False,str(ex)))
+        return report
+
     def SPS(input=1,quit_key='esc'):
         """
         Simple scissor paper rock game. Input is for 'cv2.VideoCapture(input)'
